    priorities:

    	ordered:
    		most important:

    			[ ] if "exit ()" is called by a process,
    				this might cause a problem...

    			[ ] before and after a check irregardless of whether
    				it is successful or not.

    				def after_check_1 ():
    					return;

    				def check_1 ():
    					return;

    				def before_check_1 ():
    					return;

    				checks = {
    					"check 1": {
    						"after": after_check_1,
    						"check": check_1,
    						"before": before_check_1
    					}
    				}

    				------------------------
    					def establish_1 ():
    						return;

    					establish = {
    						"establish 1": {
    							"
    						}
    					}

    			[ ] static type checking

    				https://pypi.org/project/mypy/

    			[ ] coverage
    				https://pypi.org/project/coverage/

    				subprocesses:
    					https://coverage.readthedocs.io/en/6.5.0/subprocess.html

    			[ ] capture process journal:

    					This might have binary

    					Could try utf8, the if doesn't
    					work could try hex

    					journal: [{
    						"UTF8": {
    							"parseable": "no",
    							"string": "journal entry"
    						},
    						"hexadecimal": ""
    					},{
    						"UTF8": {
    							"parseable": "no",
    							"string": "journal entry"
    						},
    						"hex": ""
    					}]

    					journal: [{
    						"UTF8": {
    							"parseable": "no"
    						},
    						"hex": [
    							"034789A987F789C987987A78987B987987987D7898F",
    						]
    					},{
    						"UTF8": {
    							"parseable": "yes"
    							"string": "journal entry"
    						}
    					},{
    						"UTF8": {
    							"parseable": "yes"
    							"string": "journal entry"
    						}
    					}]

    			[ ] "checks" or "courses"

    			[ ] The unit_tests from body_scan
    				need to be rewritten as body_scan tests
    				for OHF.

    			[ ]	global option to repeat checks if they fail,
    				since there are possibilites like "deadlocks"

    			[ ] mkdir -p, db_directory

    			[ ] print the passed checks history numbers in the results.

    					status checks [113 to 103]: [45][43][43][42][40]

    					#
    					#	That way can easily notice if that number decreases
    					#	suddenly for some reason.
    					#

    			[ ] Somehow showing processes that are still in progress,
    				in the event that one doesn't stop ever or something.

    			[ ]	A way to start multiple globs.

    				scan = OHF.start_s2 (
    					#
    					#	run globs simultaneously or
    					#
    					"simultaneous": "yes",

    					"scans": [{
    						#
    						#	required
    						#
    						"glob_string": glob_string,

    						#
    						#	optional
    						#
    						"name": "vitals",
    						"simultaneous": "yes",
    						"module_paths": [],
    						"relative_path": chassis
    					}]
    				)

    		not as important:
    			[ ] websockets to vue frontend
    				pypi "websockets"

    	unordered:
    		(body scan priorities might have more)